#include "Nunchuck.h"
#include "Arduino.h"
#include <Wire.h>

void nunchuck_setpowerpins(){
  // Uses port C (analog in) pins as power & ground for Nunchuck
  //From Wiichuck demo, Tod E. Kurt, 2008
#define pwrpin PORTC3
#define gndpin PORTC2
    DDRC |= _BV(pwrpin) | _BV(gndpin);
    PORTC &=~ _BV(gndpin);
    PORTC |=  _BV(pwrpin);
    delay(100);  // wait for things to stabilize
}

void nunchuck_init(){
 nunchuck_setpowerpins();
 Wire.begin();
 /* Initialisation du nunchuck */
 Wire.beginTransmission(NUNCHUCK_ADDRESS);
 Wire.write(0xF0);
 Wire.write(0x55);
 Wire.endTransmission();

 Wire.beginTransmission(NUNCHUCK_ADDRESS);
 Wire.write(0xFB);
 Wire.write(0x00);
 Wire.endTransmission();

 nunchuck_calibrate(); 
}



void nunchuck_read_data(){
    // on demande 6 octets au nunchuck
   Wire.requestFrom(NUNCHUCK_ADDRESS, 6);

   cpt = 0;
    // tant qu'il y a des données
   while(Wire.available()){
      // on récupère les données
     data_nunchuck[cpt] = Wire.read();
     cpt++;
   }

    // on réinitialise le nunchuck pour la prochaine demande
   Wire.beginTransmission(NUNCHUCK_ADDRESS);
   Wire.write(0x00);
   Wire.endTransmission();

   if(cpt >= 5){
      // on extrait les données
      joyX = data_nunchuck[0] - joyXCentre;
      joyY = data_nunchuck[1] - joyYCentre;
      accelX = ((data_nunchuck[2] << 2) + ((data_nunchuck[5] >> 2) & 0x03)) - accelXCentre; //MSB sur data[2] + LSB sur data[5]
      accelY = ((data_nunchuck[3] << 2) + ((data_nunchuck[5] >> 4) & 0x03)) - accelYCentre;
      accelZ = ((data_nunchuck[4] << 2) + ((data_nunchuck[5] >> 6) & 0x03)) - accelZCentre;
      boutonZ = data_nunchuck[5] & 1; //boutons Z et C : 0 si appuye, 1 si relache
      boutonC = (data_nunchuck[5] >> 1) & 1;
    }
  
}

void nunchuck_calibrate(){
  accelXCentre = 0;
  accelYCentre = 0;
  accelZCentre = 0;
  joyXCentre = 0;
  joyYCentre = 0;
  nunchuck_read_data(); //le premier tour est toujours faux
  delay(100);
  nunchuck_read_data();
  accelXCentre = accelX;
  accelYCentre = accelY;
  accelZCentre = accelZ;
  joyXCentre = joyX;
  joyYCentre = joyY;
}


void nunchuck_reinit_Z(){
  if(boutonZ==0) nunchuck_calibrate();
}


